@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.11 (default, Aug  3 2021, 15:09:35)  [GCC 7.5.0]
+# Python 3.9.5 (default, May 11 2021, 08:20:37)  [GCC 10.3.0]
 #
 # Command line options:
 #   ('--disable-generatedssuper-lookup', '')
@@ -189,6 +189,30 @@ class GeneratedsSuper(object):
             return self.__name
         def dst(self, dt):
             return None
+    def __str__(self):
+        settings = {
+            'str_pretty_print': True,
+            'str_indent_level': 0,
+            'str_namespaceprefix': '',
+            'str_name': None,
+            'str_namespacedefs': '',
+        }
+        for n in settings:
+            if hasattr(self, n):
+                setattr(settings[n], self[n])
+        from io import StringIO
+        output = StringIO()
+        self.export(
+            output,
+            settings['str_indent_level'],
+            pretty_print=settings['str_pretty_print'],
+            namespaceprefix_=settings['str_namespaceprefix'],
+            name_=settings['str_name'],
+            namespacedef_=settings['str_namespacedefs']
+        )
+        strval = output.getvalue()
+        output.close()
+        return strval
     def gds_format_string(self, input_data, input_name=''):
         return input_data
     def gds_parse_string(self, input_data, node=None, input_name=''):
@@ -199,11 +223,11 @@ class GeneratedsSuper(object):
         else:
             return input_data
     def gds_format_base64(self, input_data, input_name=''):
-        return base64.b64encode(input_data)
+        return base64.b64encode(input_data).decode('ascii')
     def gds_validate_base64(self, input_data, node=None, input_name=''):
         return input_data
     def gds_format_integer(self, input_data, input_name=''):
-        return '%d' % input_data
+        return '%d' % int(input_data)
     def gds_parse_integer(self, input_data, node=None, input_name=''):
         try:
             ival = int(input_data)
@@ -230,7 +254,7 @@ class GeneratedsSuper(object):
                 raise_parse_error(node, 'Requires sequence of integer values')
         return values
     def gds_format_float(self, input_data, input_name=''):
-        return ('%.15f' % input_data).rstrip('0')
+        return ('%.15f' % float(input_data)).rstrip('0')
     def gds_parse_float(self, input_data, node=None, input_name=''):
         try:
             fval_ = float(input_data)
@@ -969,47 +993,110 @@ def _cast(typ, value):
 # Data representation classes.
 #
 
+from .enum_import01 import Type01_1
+from .enum_import02 import Type02_1
 
-class EnumType02_1(str, Enum):
-    FLOAT='float'
-    INT='int'
-    NAME='Name'
-    TOKEN='token'
+class EnumType00_1(str, Enum):
+    """EnumType00_1 --
+    Simple type enumeration with restrictions
+    
+    """
+    FLOAT='float' # Enumeration value: 'float'
+    INT='int' # Enumeration value: 'int'
+    NAME='Name' # Enumeration value: 'Name'
+    TOKEN='token' # Enumeration value: 'token'
 
 
-class Type02_1(GeneratedsSuper):
+class Type00_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = {
-        'userdescription': MemberSpec_('userdescription', 'xs:string', 0, 0, {'name': 'userdescription', 'type': 'xs:string'}, None),
+        'inner01': MemberSpec_('inner01', 'Type01_1', 0, 0, {'name': 'inner01', 'type': 'Type01_1'}, None),
+        'inner02': MemberSpec_('inner02', 'Type02_1', 0, 0, {'name': 'inner02', 'type': 'Type02_1'}, None),
     }
     subclass = None
     superclass = None
-    def __init__(self, userdescription=None, gds_collector_=None, **kwargs_):
+    def __init__(self, inner01=None, inner02=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
-        self.userdescription = userdescription
+        self.inner01 = inner01
+        self.inner02 = inner02
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, Type02_1)
+                CurrentSubclassModule_, Type00_1)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if Type02_1.subclass:
-            return Type02_1.subclass(*args_, **kwargs_)
+        if Type00_1.subclass:
+            return Type00_1.subclass(*args_, **kwargs_)
         else:
-            return Type02_1(*args_, **kwargs_)
+            return Type00_1(*args_, **kwargs_)
     factory = staticmethod(factory)
-    def get_userdescription(self):
-        return self.userdescription
-    def set_userdescription(self, userdescription):
-        self.userdescription = userdescription
+    def get_inner01(self):
+        return self.inner01
+    def set_inner01(self, inner01):
+        self.inner01 = inner01
+    def get_inner02(self):
+        return self.inner02
+    def set_inner02(self, inner02):
+        self.inner02 = inner02
     def _hasContent(self):
         if (
-            self.userdescription is not None
+            self.inner01 is not None or
+            self.inner02 is not None
         ):
             return True
         else:
             return False
-# end class Type02_1
+# end class Type00_1
+
+
+class Type00_2(GeneratedsSuper):
+    __hash__ = GeneratedsSuper.__hash__
+    member_data_items_ = {
+        'attr1': MemberSpec_('attr1', 'enum_import01:IntType01_1', 0, 1, {'use': 'optional', 'name': 'attr1'}),
+    }
+    subclass = None
+    superclass = None
+    def __init__(self, attr1='33', gds_collector_=None, **kwargs_):
+        self.gds_collector_ = gds_collector_
+        self.attr1 = _cast(int, attr1)
+    def factory(*args_, **kwargs_):
+        if CurrentSubclassModule_ is not None:
+            subclass = getSubclassFromModule_(
+                CurrentSubclassModule_, Type00_2)
+            if subclass is not None:
+                return subclass(*args_, **kwargs_)
+        if Type00_2.subclass:
+            return Type00_2.subclass(*args_, **kwargs_)
+        else:
+            return Type00_2(*args_, **kwargs_)
+    factory = staticmethod(factory)
+    def get_attr1(self):
+        return self.attr1
+    def set_attr1(self, attr1):
+        self.attr1 = attr1
+    def validate_IntType01_1(self, value):
+        # Validate type enum_import01:IntType01_1, a restriction on xs:int.
+        if value is not None and Validate_simpletypes_ and self.gds_collector_ is not None:
+            if not isinstance(value, int):
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s is not of the correct base simple type (int)' % {"value": value, "lineno": lineno, })
+                return False
+            if value < 0:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd minInclusive restriction on IntType01_1' % {"value": value, "lineno": lineno} )
+                result = False
+            if value > 127:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd maxInclusive restriction on IntType01_1' % {"value": value, "lineno": lineno} )
+                result = False
+    def _hasContent(self):
+        if (
+
+        ):
+            return True
+        else:
+            return False
+# end class Type00_2
 
 
 GDSClassesMapping = {
@@ -1020,5 +1107,8 @@ RenameMappings_ = {
 
 }
 __all__ = [
+    "Type00_1",
+    "Type00_2",
+    "Type01_1",
     "Type02_1"
 ]
