@@ -3,7 +3,7 @@
 
 #
 # Generated  by generateDS.py.
-# Python 3.8.11 (default, Aug  3 2021, 15:09:35)  [GCC 7.5.0]
+# Python 3.9.5 (default, May 11 2021, 08:20:37)  [GCC 10.3.0]
 #
 # Command line options:
 #   ('--no-dates', '')
@@ -190,6 +190,30 @@ class GeneratedsSuper(object):
             return self.__name
         def dst(self, dt):
             return None
+    def __str__(self):
+        settings = {
+            'str_pretty_print': True,
+            'str_indent_level': 0,
+            'str_namespaceprefix': '',
+            'str_name': None,
+            'str_namespacedefs': '',
+        }
+        for n in settings:
+            if hasattr(self, n):
+                setattr(settings[n], self[n])
+        from io import StringIO
+        output = StringIO()
+        self.export(
+            output,
+            settings['str_indent_level'],
+            pretty_print=settings['str_pretty_print'],
+            namespaceprefix_=settings['str_namespaceprefix'],
+            name_=settings['str_name'],
+            namespacedef_=settings['str_namespacedefs']
+        )
+        strval = output.getvalue()
+        output.close()
+        return strval
     def gds_format_string(self, input_data, input_name=''):
         return input_data
     def gds_parse_string(self, input_data, node=None, input_name=''):
@@ -200,11 +224,11 @@ class GeneratedsSuper(object):
         else:
             return input_data
     def gds_format_base64(self, input_data, input_name=''):
-        return base64.b64encode(input_data)
+        return base64.b64encode(input_data).decode('ascii')
     def gds_validate_base64(self, input_data, node=None, input_name=''):
         return input_data
     def gds_format_integer(self, input_data, input_name=''):
-        return '%d' % input_data
+        return '%d' % int(input_data)
     def gds_parse_integer(self, input_data, node=None, input_name=''):
         try:
             ival = int(input_data)
@@ -231,7 +255,7 @@ class GeneratedsSuper(object):
                 raise_parse_error(node, 'Requires sequence of integer values')
         return values
     def gds_format_float(self, input_data, input_name=''):
-        return ('%.15f' % input_data).rstrip('0')
+        return ('%.15f' % float(input_data)).rstrip('0')
     def gds_parse_float(self, input_data, node=None, input_name=''):
         try:
             fval_ = float(input_data)
